@@ -63,12 +63,11 @@
      ((string=? (car defs) str) #t)
      (else (loop (cdr defs))))))
 
-(define (c99-std-val str)
+(define (c99-std-val str sl)
   (cond
    ((string=? str "__DATE__") "M01 01 2001")
-   ((string=? str "__FILE__") "(unknown)")
-   ;;((string=? str "__LINE__") "0")
-   ((string=? str "__LINE__") (number->string (random 10000)))
+   ((string=? str "__FILE__") (or (assq-ref sl 'filename) "(unknown)"))
+   ((string=? str "__LINE__") (number->string (or (assq-ref sl 'line) 0)))
    ((string=? str "__STDC__") "1")
    ((string=? str "__STDC_HOSTED__") "0")
    ((string=? str "__STDC_VERSION__") "201701")
@@ -89,9 +88,10 @@
 ;; This reads the rest of the input, with ch and returns a string;
 ;; Replaces get-string-all from (ice-9 textual-ports).
 (define (read-rest ch)
-  (list->string (let loop ((ch ch))
-		  (if (eof-object? ch) '()
-		      (cons ch (loop (read-char)))))))
+  (reverse-list->string
+   (let loop ((res '())(ch ch))
+     (if (eof-object? ch) res
+         (loop (cons ch res) (read-char))))))
 
 ;; Not sure about this. We want to turn a list of tokens into a string
 ;; with proper escapes.
@@ -476,7 +476,7 @@
 	   (else 
 	    (loop rr (acons '$ident iden tkl) lv (read-char)))))
 	 (else
-	  (let ((rval (expand-cpp-macro-ref iden defs used)))
+	  (let ((rval (expand-cpp-macro-ref iden defs '() used)))
 	    (if rval
 		(loop #t (cons rval tkl) lv (read-char))
 		(loop rr (acons '$ident iden tkl) lv (read-char))))))))
@@ -619,7 +619,7 @@
      (report-error fmt args)
      (throw 'c99-error "CPP error"))))
 
-;; @deffn {Procedure} expand-cpp-macro-ref ident defs [used] => repl|#f
+;; @deffn {Procedure} expand-cpp-macro-ref ident defs sl [used] => repl|#f
 ;; Given an identifier seen in the current input, this checks for associated
 ;; definition in @var{defs} (generated from CPP defines).  If found as simple
 ;; macro, the expansion is returned as a string.  If @var{ident} refers
@@ -632,8 +632,9 @@
 ;; @noindent
 ;; Note that this routine will look in the current-input so if you want to
 ;; expand text, BE CAREFUL AND USE (with-input-from-string "" ...)
+;; The argument @var{sl} is source location info.
 ;; @end deffn
-(define* (expand-cpp-macro-ref ident defs #:optional (used '()))
+(define* (expand-cpp-macro-ref ident defs sl #:optional (used '()))
   (let ((rval (assoc-ref defs ident)))
     (cond
      ((member ident used) #f)
@@ -641,7 +642,7 @@
       (let* ((used (cons ident used))
 	     (repl (cpp-expand-text rval defs used)))
 	(if (ident-like? repl)
-	    (or (expand-cpp-macro-ref repl defs used) repl)
+	    (or (expand-cpp-macro-ref repl defs sl used) repl)
 	    repl)))
      ((pair? rval)
       ;; GNU CPP manual: "A function-like macro is only expanded if its name
@@ -653,9 +654,9 @@
 		      (prep (px-cpp-ftn argd (cdr rval)))
 		      (repl (cpp-expand-text prep defs used)))
 		 (if (ident-like? repl)
-		     (or (expand-cpp-macro-ref repl defs used) repl)
+		     (or (expand-cpp-macro-ref repl defs sl used) repl)
 		     repl)))))
-     ((c99-std-val ident) => identity)
+     ((c99-std-val ident sl) => identity)
      ;;((string=? ident "_Pragma") (finish-pragma))
      ;;^ does not work here: move here when cpp is token-based
      (else #f))))
@@ -680,8 +681,8 @@
 ;; Calls @code{expand-cpp-macro-ref} with null input string (w/o further
 ;; input).  If @var{name} is has a function definition @code{#f} is returned.
 ;; @end deffn
-(define (expand-cpp-name name defs)
+(define (expand-cpp-name name defs sl)
   (with-input-from-string ""
-    (lambda () (expand-cpp-macro-ref name defs))))
+    (lambda () (expand-cpp-macro-ref name defs sl))))
 
 ;;; --- last line ---
